TRACKERS = [
    "udp://tracker.opentrackr.org:1337/announce",
    "udp://open.demonii.com:1337/announce",
    "udp://tracker.rarbg.to:80/announce",
    "udp://tracker.blackunicorn.xyz:6969/announce",
    "udp://tracker.filetracker.pl:6969/announce",
    "udp://tracker.istole.it:80/announce",
    "udp://tracker.tiny-vps.com:6969/announce",
    "udp://9.rarbg.me:2710/announce",
    "udp://tracker.eztv.ch:80/announce",
    "udp://tracker.yify-torrents.com:1337/announce",
    "udp://tracker.torrenty.org:6969/announce",
    "udp://tracker.yify-torrents.com:6969/announce",
    "udp://tracker.filetracker.pl:8082/announce",
    "udp://tracker.zer0day.to:1337/announce",
    "udp://tracker.filetracker.pl:8089/announce",
    "udp://tracker.ettv.be:80/announce",
    "udp://tracker.mg64.net:6881/announce",
    "udp://tracker.coppersurfer.tk:80/announce",
    "udp://tracker.piratepublic.com:1337/announce",
    "udp://9.rarbg.to:2710/announce",
    "udp://tracker.filetracker.pl:1337/announce",
    "udp://tracker.yify-torrents.com:9090/announce",
    "udp://tracker.internetwarriors.net:1337/announce",
    "udp://tracker.mg64.net:2710/announce",
    "udp://tracker.filetracker.pl:80/announce",
    "udp://tracker.open-internet.nl:6969/announce",
    "udp://tracker.coppersurfer.tk:6969/announce",
    "udp://tracker.mg64.net:6969/announce",
    "udp://tracker.mgtracker.org:2710/announce",
    "udp://tracker.openbittorrent.com:80/announce",
    "udp://public.popcorn-tracker.org:6969/announce",
    "udp://tracker.yify-torrents.com:80/announce",
    "udp://tracker.yify-torrents.com:8080/announce",
    "udp://exodus.desync.com:6969/announce",
    "udp://tracker.internet",
    "udp://tracker.grepler.com:6969/announce",
    "udp://tracker.justseed.it:1337/announce",
    "udp://tracker.leechers-paradise.org:6969/announce",
    "udp://tracker.torrent.eu.org:451/announce",
    "udp://tracker.cyberia.is:6969/announce",
    "udp://tracker.limetorrents.com:80/announce",
    "http://tracker.thepiratebay.org/announce",
    "udp://tracker.filetracker.pl:8080/announce",
    "udp://tracker.1337x.org:80/announce",
    "udp://9.rarbg.com:2710/announce",
    "udp://tracker.filetracker.pl:8081/announce",
]


DHT_NODES = [
    ("router.bittorrent.com", 6881),
    ("dht.aelitis.com", 6881),
    ("dht.libtorrent.org", 6881),
    ("router.silotis.us", 6881),
    ("dht.libtorrent.org", 25401),
    ("router.utorrent.com", 6881),
    ("router.bitcomet.com", 6881),
    ("dht.transmissionbt.com", 6881),
    ("dht.bittorrent.com", 6881),
    ("router.bittorrent.com", 6881),
]
